#!/usr/bin/perl
#
#  This small scripts expands frame definition summary table 
#  of the following format:
#
#   <name1>   <ref_frame_1>   <CK/FIXED>  <id1>
#     ...          ...            ...      ... 
#   <nameN>   <ref_frame_N>   <CK/FIXED>  <idN>
# 
#  to the corresponding sets of keywords.
#
#  The script takes two command line arguments -- name of a file containing 
#  table and name of the a file the definitions will be written to.
#  
#  BVS/NAIF, June 12, 2001
#

if ( @ARGV == 2 ) {
   $table = shift @ARGV;
   if ( ! -e $table ) {
      die "\nInput table file $table doesn't exist.\n\n";
   }
   $defs = shift @ARGV;
   if ( -e $defs ) {
      die "\nOutput defs file $defs already exists.\n\n";
   }
} else {
   die "\nUsage:\n\n   make_fk_defs.pl <input_table_file> <output_defs_file>\n\n";
}

open ( TABLE, "<$table" ) || die "\nCannot open input table file $table.\n\n";
open ( DEFS, ">$defs" ) || die "\nCannot open output defs file $defs.\n\n";

while ( $line = <TABLE> ) {

   chop( $line );
   
   #
   #  Skip blank lines.
   #
   if ( ! ( $line =~ /^\s*$/ ) ) {
   
      #
      #  Split current line into fields.
      #
      ($name,$relto,$type,$id) = split( ' ', $line );
      
      #
      #  Compute nominal SCLK and SPK ID for CK frame.
      #
      if ( $id < -1000 ) {
         $sclkid = int( $id / 1000 ); 
         $center = $sclkid;
      }
      
      #
      #  Pad name with a blanks for nicer output.
      #
      $namepad = substr( $name."                             ", 0, 
                       26  - 7 + length($id) );
 
      #
      #  Print frame subsection header.
      #
      
      print DEFS <<"EndOfText";
      
      
$name Frame
-------------------------------------------------------------------------------

   $name frame is a $type frame with its orientation given
   relative to the $relto frame.

   $name frame is defined as follows:
      -  Z axis is along <<TBD>> ;
      -  Y axis is along <<TBD>> ;
      -  X complements to the right hand frame; <<TBD>> ;

   The origin of the $name frame is located at <<TBD>> .
EndOfText

      #
      #  Depending on the frame type print definition print corresponding 
      #  definition keywords.
      #
      if      ( $type =~ /FIXED/i ) {
      
         print DEFS <<"EndOfText";

   Since the frame definition below contains reverse transformation, from 
   the frame to the reference, the order of rotations assigned to the 
   TKFRAME_*_AXES keyword is also reversed and the signs of rotation angles 
   assigned to the TKFRAME_*_ANGLES keyword are changed to the opposite ones.

   \\begindata

      FRAME_$namepad =  $id
      FRAME_${id}_NAME               = '$name'
      FRAME_${id}_CLASS              =  4
      FRAME_${id}_CLASS_ID           =  $id
      FRAME_${id}_CENTER             =  $center

      TKFRAME_${id}_RELATIVE         = '$relto'
      TKFRAME_${id}_SPEC             = 'ANGLES'
      TKFRAME_${id}_UNITS            = 'DEGREES'
      TKFRAME_${id}_AXES             = (   1,       2,       3     )
      TKFRAME_${id}_ANGLES           = ( 000.000, 000.000, 000.000 )
                                        
   \\begintext
EndOfText

      
      } elsif ( $type =~ /CK/i    ) {

      print DEFS <<"EndOfText";
      
   \\begindata

      FRAME_$namepad = $id
      FRAME_${id}_NAME               = '$name'
      FRAME_${id}_CLASS              =  3
      FRAME_${id}_CLASS_ID           = $id
      FRAME_${id}_CENTER             = $center

      CK_${id}_SCLK                  = $sclkid
      CK_${id}_SPK                   = $center

   \\begintext
EndOfText

      } else {
         die "\Cannot interprete frame type $type. Type can be ".
             "only CK or FIXED.\n\n";
      }
      
   }

}

print DEFS "\n";

close ( TABLE ) || die "\nCannot close input table file $table.\n\n";
close ( DEFS ) || die "\nCannot close output defs file $defs.\n\n";

exit;
