#!/bin/csh
#
#  This script creates complete PDS directory structure with zero-size
#  file placeholders for all generic meta-info/aareadme files in the 
#  locations and with the names they should have on an actual PDS SPICE
#  data set.
#
#  Usage:
#
#     % make_pds_directories.csh <directory_name>
#
#  where 
#
#     directory_name    is the name of the directory under which PDS SPICE
#                       directory tree will be created. This must be 
#                       name of non-existing directory.
#
#  BVS/NAIF, January 3, 2000
#
#     Script was updated to create directories with uppercase names
#     and to reduce number of DS files (SPICEDS.CAT instead of many.)
#
#  BVS/NAIF, April 26, 1999
#

#
#  Get command line argument
#
if ( $#argv != 1 ) then 
   echo " "
   echo "Usage: % make_pds_directories.csh <directory_name> "
   echo " "
   exit
else
   set TOPDIR = $1
endif

#
#  Check whether provided directory already exists.
#
if ( -e $TOPDIR ) then 
   echo " "
   echo "ERROR: Directory '$TOPDIR' specified on the command line already exists."
   echo " "
   exit
endif

#
#  Create top level directory.
#
mkdir $TOPDIR
if ( ! $status == 0 ) then
   echo " "
   echo "ERROR: Couldn't create directory '$TOPDIR'."
   echo " "
   exit
endif

#
#  Create complete PDS directory structure.
#
mkdir $TOPDIR/CATALOG
mkdir $TOPDIR/DATA
mkdir $TOPDIR/DATA/CK
mkdir $TOPDIR/DATA/EK
mkdir $TOPDIR/DATA/FK
mkdir $TOPDIR/DATA/IK
mkdir $TOPDIR/DATA/LSK
mkdir $TOPDIR/DATA/PCK
mkdir $TOPDIR/DATA/SCLK
mkdir $TOPDIR/DATA/SPK
mkdir $TOPDIR/DOCUMENT
mkdir $TOPDIR/INDEX
mkdir $TOPDIR/SOFTWARE

#
#  Create complete set of meta-data/aareadme placeholder files.
#
touch $TOPDIR/AAREADME.TXT
touch $TOPDIR/AAREADME.HTM
touch $TOPDIR/VOLDESC.CAT
touch $TOPDIR/ERRATA.TXT
touch $TOPDIR/CATALOG/CATINFO.TXT
touch $TOPDIR/CATALOG/SPICEDS.CAT
touch $TOPDIR/CATALOG/REF.CAT
touch $TOPDIR/CATALOG/INSTHOST.CAT
touch $TOPDIR/CATALOG/MISSION.CAT
touch $TOPDIR/CATALOG/PERSON.CAT
touch $TOPDIR/DATA/CK/CKINFO.TXT
touch $TOPDIR/DATA/EK/EKINFO.TXT
touch $TOPDIR/DATA/FK/FKINFO.TXT
touch $TOPDIR/DATA/IK/IKINFO.TXT
touch $TOPDIR/DATA/LSK/LSKINFO.TXT
touch $TOPDIR/DATA/PCK/PCKINFO.TXT
touch $TOPDIR/DATA/SCLK/SCLKINFO.TXT
touch $TOPDIR/DATA/SPK/SPKINFO.TXT
touch $TOPDIR/DOCUMENT/DOCINFO.TXT
touch $TOPDIR/DOCUMENT/LBLINFO.TXT
touch $TOPDIR/DOCUMENT/ONLABELS.TXT
touch $TOPDIR/INDEX/INDXINFO.TXT
touch $TOPDIR/INDEX/INDEX.TAB
touch $TOPDIR/INDEX/INDEX.LBL
touch $TOPDIR/SOFTWARE/SOFTINFO.TXT

#
#  Display listing of created directories/placeholders.
#
echo " "
echo "-----------------------------------------------------------------"
echo " "
echo "The following directory sctructure/placeholder files were created"
echo "under $TOPDIR :"
echo " "
echo "-----------------------------------------------------------------"
echo " "

ls -lFR $TOPDIR

echo " "
echo "-----------------------------------------------------------------"
echo " "

