#!/bin/csh
#
#  This script recursively converts to uppercase names of all 
#  files in current directory and its subdirectories.
#
#  BVS/NAIF, January 3, 2000.
#

foreach FF ( `find . -name '*' -print` )

   #
   #  Convert full names (including subdirectories incorporated
   #  in it) to uppercase.
   #
   set UFF = `echo $FF | tr a-z A-Z`
   
   #
   #  Check whether file with uppercased name already exists.
   #
   if ( -e $UFF ) then
      
      #
      #  It does. Check whether it's a directory.
      #
      if ( -d $UFF ) then
      
         #
         #  It is. We simply leave directories alone.
         #
   
      else
      
         #
         #  It's a file. Check whether the original file name 
         #  was uppercase already.
         #
         if ( $FF == $UFF )  then
            
            #
            #  The name was already uppercase. It's OK. We need 
            #  to do nothing.
            #
            
         else
         
            #
            #  It looks like we have name conflict. Report about it
            #  and proceed further.
            #
            echo "File $UFF already exists. Cannot move $FF to it."
            
         endif
         
      endif
      
   else
   
      #
      #  It doesn't. We "rename" the file.
      #
      mv $FF $UFF
      
   endif
   
end

exit

