#!/bin/csh

#
#  This script check whether all requred PDS files are present on the 
#  master image volume (the one with all UNIX files with CRs added.)
#
#  This is a super-duper-light version of the PDS's VVTOOL :-). So,
#  don't expect much from it ...
#  
#  BVS/NAIF, April 25, 2000.
#
#     Added second pass capturing all text files (*.TXT, *.LBL, *.CAT ...)
#
#  BVS/NAIF, January 10, 2000.
#
#     Updated line length check to be for 78 char.
#
#  BVS/NAIF, January 5, 2000.
#

#
#  badchar executable
#
set BADCHAR = '/home/bsemenov/bin/badchar'

echo " "
echo "Problems are marked with (E) in at the beginnng of report lines."
echo " "
#
#  Checking directories.
#
echo "   Verifying directories:"
echo " "

foreach DD ( CATALOG DATA DATA/CK DATA/EK DATA/FK DATA/IK DATA/LSK DATA/PCK DATA/SCLK DATA/SPK DOCUMENT INDEX SOFTWARE )
   
   #
   #  Does it exist?
   #
   if ( -e $DD ) then
   
      #
      #  Is it a directory?
      #
      if ( -d $DD ) then
         echo "      $DD exists and is a directory."
      else
         echo "(E)   $DD is not a directory."
      endif
      
   else
      echo "(E)   $DD doesn't exist."     
   endif

end

#
#  Checking files.
#
echo " "
echo "   Verifying files -- first pass is over REQUIRED files:"
echo " "

foreach FF ( AAREADME.HTM AAREADME.LBL AAREADME.TXT CATALOG/CATINFO.TXT CATALOG/INSTHOST.CAT CATALOG/MISSION.CAT CATALOG/PERSON.CAT CATALOG/REF.CAT CATALOG/SPICEDS.CAT DATA/CK/CKINFO.TXT DATA/EK/EKINFO.TXT DATA/FK/FKINFO.TXT DATA/IK/IKINFO.TXT DATA/LSK/LSKINFO.TXT DATA/PCK/PCKINFO.TXT DATA/SCLK/SCLKINFO.TXT DATA/SPK/SPKINFO.TXT DOCUMENT/DOCINFO.TXT DOCUMENT/LBLINFO.TXT DOCUMENT/ONLABELS.TXT INDEX/INDEX.LBL INDEX/INDEX.TAB INDEX/INDXINFO.TXT SOFTWARE/SOFTINFO.TXT VOLDESC.CAT )

   #
   #  Does it exist?
   #
   if ( -e $FF ) then
   
      #
      #  Does it have non-zero size?
      #
      if ( ! ( -z $FF ) ) then
      
         #
         #  Does it have any bad characters?
         #
         $BADCHAR -s $FF
         
         if ( $status != 1 ) then
            
            #
            #  Does it have lines longer than 78 characters?
            #
            awk -e '{if(length>78){print $0}}' < $FF | grep '.' > /dev/null
            
            if ( ( $status != 0 ) || $FF == "AAREADME.HTM" || $FF == "INDEX/INDEX.TAB" ) then
               
               echo "      $FF is OK."
               
            else
               #
               #  Yes it does. Run awk again to dump these lines.
               #
               echo "(E)   $FF has lines longer than 78 char. They are:"
               echo " "
               awk -e '{if(length>78){print $0}}' < $FF
               echo " "
            endif
            
         else
            #
            #  Yes, it does have bad characters. Run badchar again
            #  to generate report.
            #
            echo "(E)   $FF has bad characaters. badchar report is:"
            echo " "
            $BADCHAR -v $FF
            echo " "
         endif

      else
         echo "(E)   $FF has zero size."
      endif
      
   else
      echo "(E)   $FF doesn't exist."     
   endif

end

#
#  Checking files.
#
echo " "
echo "   Verifying files -- second pass is over all text files:"
echo " "

foreach FF ( `find . -name '*.LBL' -print` `find . -name '*.TXT' -print` `find . -name '*.CAT' -print` `find . -name '*.HTM' -print` `find . -name '*.TAB' -print`)

   #
   #  Does it exist?
   #
   if ( -e $FF ) then
   
      #
      #  Does it have non-zero size?
      #
      if ( ! ( -z $FF ) ) then
      
         #
         #  Does it have any bad characters?
         #
         $BADCHAR -s $FF
         
         if ( $status != 1 ) then
            
            #
            #  Does it have lines longer than 78 characters?
            #
            awk -e '{if(length>78){print $0}}' < $FF | grep '.' > /dev/null
            
            if ( ( $status != 0 ) || $FF:e == "HTM" || $FF:e == "TAB" ) then
               
               echo "      $FF is OK."
               
            else
               #
               #  Yes it does. Run awk again to dump these lines.
               #
               echo "(E)   $FF has lines longer than 78 char. They are:"
               echo " "
               awk -e '{if(length>78){print $0}}' < $FF
               echo " "
            endif
            
         else
            #
            #  Yes, it does have bad characters. Run badchar again
            #  to generate report.
            #
            echo "(E)   $FF has bad characaters. badchar report is:"
            echo " "
            $BADCHAR -v $FF
            echo " "
         endif

      else
         echo "(E)   $FF has zero size."
      endif
      
   else
      echo "(E)   $FF doesn't exist."     
   endif

end
echo " "
echo "All done."
echo " "

exit