C$Procedure      FDPOOL ( First value of a kernel pool variable )
 
      SUBROUTINE FDPOOL ( NAME, FIRST, WHICH, FOUND )
 
C$ Abstract
C
C     Retrieve the first value (in the sense of ordering d.p. values)
C     associated with a kernel pool variable.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C      None.
C
C$ Keywords
C
C      POOL
C
C$ Declarations
 
      IMPLICIT NONE
      CHARACTER*(*)         NAME
      DOUBLE PRECISION      FIRST
      INTEGER               WHICH
      LOGICAL               FOUND
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAME       I   Name of a kernel pool variable
C     FIRST      O   First value for NAME.
C     WHICH      O   Index of FIRST in array of values for NAME
C     FOUND      O   TRUE if NAME is in the kernel pool. Otherwise FALSE
C
C$ Detailed_Input
C
C     NAME       Name of a kernel pool variable
C
C$ Detailed_Output
C
C     FIRST      Value of the smallest d.p. associated with NAME
C
C     WHICH      is the index of FIRST in the set of values for NAME.
C                If a NAME  is not present, WHICH is returned
C                with the value 0.
C
C     FOUND      is returned TRUE if NAME is in the kernel pool.
C                Otherwise it is returned FALSE.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This routine helps with the task of retrieving the value
C     associated with a kernel pool variable in numeric order.
C
C$ Examples
C
C     To fetch the values in ascending order for a kernel pool variable
C     use this routine together with NDPOOL as shown here.
C
C     Get the first value.
C
C        CALL FDPOOL ( NAME, THIS, WHICH, FOUND )
C
C        DO WHILE ( WHICH .GT. 0 )
C
C           Do something with THIS.  Then fetch
C           the NEXT value.
C
C           LAST = THIS
C           CALL NDPOOL ( NAME, LAST, THIS, WHICH, FOUND )
C
C        END DO
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 31-MAR-2000 (WLT)
C
C
C-&
 
C$ Index_Entries
C
C     smallest value of a kernel pool variable
C
C-&
 
      INTEGER               ROOM
      PARAMETER           ( ROOM = 32 )
 
 
      INTEGER               CASE
      INTEGER               I
      INTEGER               N
 
      DOUBLE PRECISION      VALUES ( ROOM )
 
      WHICH = 0
      CASE  = 1
      N     = 0
 
      CALL GDPOOL ( NAME, CASE, ROOM, N, VALUES, FOUND )
      
      IF ( .NOT. FOUND ) THEN
         RETURN
      END IF
         
      
      DO WHILE ( N .GT. 0 )
 
         DO I = 1, N
 
            IF ( WHICH .EQ. 0 ) THEN
               FIRST  = VALUES(I)
               WHICH = CASE + I - 1
            ELSE IF ( VALUES(I) .LT. FIRST ) THEN
               FIRST  = VALUES(I)
               WHICH = CASE + I - 1
            END IF
 
         END DO
 
         IF ( N .EQ. ROOM ) THEN
            CASE = CASE + ROOM
            CALL GDPOOL ( NAME, CASE, ROOM, N, VALUES, FOUND )
         ELSE
            N = 0
         END IF
 
      END DO
 
      RETURN
      END
