C$Procedure      ZZAXUTIL ( Axis Utility )
 
      LOGICAL FUNCTION ZZAXUTIL ( AXIS )
 
C$ Abstract
C
C     SPICE Private routine intended solely for the support of SPICE
C     routines.  Users should not call this routine directly due
C     to the volatile nature of this routine.
C
C     This function returns information about the axis specified
C     through the string AXIS.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     UTILITY
C
C$ Declarations
 
      IMPLICIT NONE
      CHARACTER*(*)         AXIS
      LOGICAL               ZZDOFLIP
      LOGICAL               ZZONEWRD
      INTEGER               ZZWHCHAX
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  ENTRY POINT
C     --------  ---  --------------------------------------------------
C     AXIS       I   ZZWHCHAX, ZZDOFLIP
C
C
C
C$ Detailed_Output
C
C     The various entry points return information about the axis
C     specified.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This is a utility that serves as an umbrella for other
C     entry  points functions that return information about
C     the specified axis
C
C$ Examples
C
C     See the other entry points.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 07-AUG-2000 (WLT)
C
C
C-&
C     Spicelib Functions
C
      INTEGER               BSRCHC
 
      CHARACTER*(3)         KNOWN ( 18 )
      INTEGER               WHICH ( 18 )
      LOGICAL               FLIP  ( 18 )
      LOGICAL               ORDER ( 18 )
 
      LOGICAL               FIRST
 
      SAVE                  KNOWN
      SAVE                  WHICH
      SAVE                  FLIP
      SAVE                  FIRST
 
 
      CHARACTER*(3)         MYAXIS
      INTEGER               B
      INTEGER               E
      INTEGER               I
      INTEGER               START
 
      DATA                  FIRST   / .TRUE. /
 
 
 
      ZZAXUTIL = .FALSE.
      RETURN
 
 
C$Procedure ZZDOFLIP (meaning)
 
      ENTRY ZZDOFLIP ( AXIS )
 
C$ Abstract
C
C     SPICE Private routine intended solely for the support of SPICE
C     routines.  Users should not call this routine directly due
C     to the volatile nature of this routine.
C
C     Inidicate whether AXIS is + or - {X,Y,Z}
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     KEYWORD
C
C$ Declarations
C
C     CHARACTER*(*)         AXIS
C
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AXIS       I   specification of an axis (+/- xyz)
C
C$ Detailed_Input
C
C     AXIS       axis specification
C
C$ Detailed_Output
C
C     The function returns .TRUE. if the first character is '-'
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) Signals the error 'SPICE(UNKNOWN_AXIS)' if the axis is not
C        recognized.
C
C$ Particulars
C
C     Returns .TRUE. if the axis is -x, -y, or -z.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 07-AUG-2000 (WLT)
C
C
C-&
C
C     Initialization block
C
      IF ( FIRST ) THEN
         FIRST     = .FALSE.
 
         KNOWN( 1) = '+X'
         KNOWN( 2) = '+Y'
         KNOWN( 3) = '+Z'
         KNOWN( 4) = '+x'
         KNOWN( 5) = '+y'
         KNOWN( 6) = '+z'
         KNOWN( 7) = '-X'
         KNOWN( 8) = '-Y'
         KNOWN( 9) = '-Z'
         KNOWN(10) = '-x'
         KNOWN(11) = '-y'
         KNOWN(12) = '-z'
         KNOWN(13) = 'X'
         KNOWN(14) = 'Y'
         KNOWN(15) = 'Z'
         KNOWN(16) = 'x'
         KNOWN(17) = 'y'
         KNOWN(18) = 'z'
 
 
         FLIP ( 1) = .FALSE.
         FLIP ( 2) = .FALSE.
         FLIP ( 3) = .FALSE.
         FLIP ( 4) = .FALSE.
         FLIP ( 5) = .FALSE.
         FLIP ( 6) = .FALSE.
         FLIP ( 7) = .TRUE.
         FLIP ( 8) = .TRUE.
         FLIP ( 9) = .TRUE.
         FLIP (10) = .TRUE.
         FLIP (11) = .TRUE.
         FLIP (12) = .TRUE.
         FLIP (13) = .FALSE.
         FLIP (14) = .FALSE.
         FLIP (15) = .FALSE.
         FLIP (16) = .FALSE.
         FLIP (17) = .FALSE.
         FLIP (18) = .FALSE.
 
 
         WHICH( 1) = 1
         WHICH( 2) = 2
         WHICH( 3) = 3
         WHICH( 4) = 1
         WHICH( 5) = 2
         WHICH( 6) = 3
         WHICH( 7) = 1
         WHICH( 8) = 2
         WHICH( 9) = 3
         WHICH(10) = 1
         WHICH(11) = 2
         WHICH(12) = 3
         WHICH(13) = 1
         WHICH(14) = 2
         WHICH(15) = 3
         WHICH(16) = 1
         WHICH(17) = 2
         WHICH(18) = 3
 
         CALL ORDERC ( KNOWN, 18, ORDER )
 
         CALL REORDC ( ORDER, 18, KNOWN )
         CALL REORDL ( ORDER, 18, FLIP  )
         CALL REORDI ( ORDER, 18, WHICH )
 
      END IF
 
      CALL CMPRSS ( ' ', 0, AXIS, MYAXIS )
 
      I = BSRCHC ( MYAXIS, 18, KNOWN )
 
      IF ( I .GT. 0 ) THEN
         ZZDOFLIP = FLIP(I)
      ELSE
         ZZDOFLIP = .FALSE.
         CALL CHKIN ( 'ZZDOFLIP' )
         CALL SETMSG ( 'The axis ''#'' is not recognized.' )
         CALL ERRCH  ( '#', AXIS )
         CALL SIGERR( 'SPICE(UNKNOWN_AXIS)' )
         CALL CHKOUT ( 'ZZDOFLIP' )
      END IF
 
      RETURN
 
 
C$Procedure      ZZWHCHAX ( Which axis )
 
      ENTRY ZZWHCHAX ( AXIS )
 
C$ Abstract
C
C     SPICE Private routine intended solely for the support of SPICE
C     routines.  Users should not call this routine directly due
C     to the volatile nature of this routine.
C
C     Return the index of the coordinate axis.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     Utility
C
C$ Declarations
C
C
C     IMPLICIT NONE
C     CHARACTER*(*)         AXIS
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AXIS       I   String describing a coordinate axis.
C
C$ Detailed_Input
C
C     AXIS       is one of [+]/- x,y,z  (case insensitive).
C
C$ Detailed_Output
C
C
C     The function returns 1,2, or 3 (corresponding to x, y, or z axis)
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     1) Signals the error 'SPICE(UNKNOWN_AXIS)' if the axis is not
C        recognized.
C
C$ Particulars
C
C     Returns 1, 2, or 3 if the axis is x, y, or z respectively.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 07-AUG-2000 (WLT)
C
C
C-&
 
 
      IF ( FIRST ) THEN
         FIRST     = .FALSE.
 
         KNOWN( 1) = '+X'
         KNOWN( 2) = '+Y'
         KNOWN( 3) = '+Z'
         KNOWN( 4) = '+x'
         KNOWN( 5) = '+y'
         KNOWN( 6) = '+z'
         KNOWN( 7) = '-X'
         KNOWN( 8) = '-Y'
         KNOWN( 9) = '-Z'
         KNOWN(10) = '-x'
         KNOWN(11) = '-y'
         KNOWN(12) = '-z'
         KNOWN(13) = 'X'
         KNOWN(14) = 'Y'
         KNOWN(15) = 'Z'
         KNOWN(16) = 'x'
         KNOWN(17) = 'y'
         KNOWN(18) = 'z'
 
 
         FLIP ( 1) = .FALSE.
         FLIP ( 2) = .FALSE.
         FLIP ( 3) = .FALSE.
         FLIP ( 4) = .FALSE.
         FLIP ( 5) = .FALSE.
         FLIP ( 6) = .FALSE.
         FLIP ( 7) = .TRUE.
         FLIP ( 8) = .TRUE.
         FLIP ( 9) = .TRUE.
         FLIP (10) = .TRUE.
         FLIP (11) = .TRUE.
         FLIP (12) = .TRUE.
         FLIP (13) = .FALSE.
         FLIP (14) = .FALSE.
         FLIP (15) = .FALSE.
         FLIP (16) = .FALSE.
         FLIP (17) = .FALSE.
         FLIP (18) = .FALSE.
 
 
         WHICH( 1) = 1
         WHICH( 2) = 2
         WHICH( 3) = 3
         WHICH( 4) = 1
         WHICH( 5) = 2
         WHICH( 6) = 3
         WHICH( 7) = 1
         WHICH( 8) = 2
         WHICH( 9) = 3
         WHICH(10) = 1
         WHICH(11) = 2
         WHICH(12) = 3
         WHICH(13) = 1
         WHICH(14) = 2
         WHICH(15) = 3
         WHICH(16) = 1
         WHICH(17) = 2
         WHICH(18) = 3
 
         CALL ORDERC ( KNOWN, 18, ORDER )
 
         CALL REORDC ( ORDER, 18, KNOWN )
         CALL REORDL ( ORDER, 18, FLIP  )
         CALL REORDI ( ORDER, 18, WHICH )
 
      END IF
 
      CALL CMPRSS ( ' ', 0, AXIS, MYAXIS )
 
      I = BSRCHC ( MYAXIS, 18, KNOWN )
 
      IF ( I .GT. 0 ) THEN
         ZZWHCHAX = WHICH(I)
      ELSE
         ZZWHCHAX = 0
         CALL CHKIN ( 'ZZWHCHAX' )
         CALL SETMSG ( 'The axis ''#'' is not recognized.' )
         CALL ERRCH  ( '#', AXIS )
         CALL SIGERR( 'SPICE(UNKNOWN_AXIS)' )
         CALL CHKOUT ( 'ZZWHCHAX' )
      END IF
 
      RETURN
 
 
C$Procedure      ZZONEWRD ( One word )
 
      ENTRY ZZONEWRD ( AXIS )
 
C$ Abstract
C
C     SPICE Private routine intended solely for the support of SPICE
C     routines.  Users should not call this routine directly due
C     to the volatile nature of this routine.
C
C     Return true in the input string consists of a single word.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     UTILITY
C
C$ Declarations
C
C
C     IMPLICIT NONE
C     CHARACTER*(*)         AXIS
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AXIS       I   String to be examined
C
C     The function returns TRUE if AXIS consists of a single word.
C
C$ Detailed_Input
C
C     AXIS      a string that consists of zero or more words.
C
C$ Detailed_Output
C
C
C
C     The function returns TRUE is AXIS contains just one word.
C     Otherwise it returns .FALSE.  (including the case of a blank
C     string).
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     This routine lets us know if AXIS consists of a single word.
C
C$ Examples
C
C     None.
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 07-AUG-2000 (WLT)
C
C
C-&
 
 
      START = 1
      CALL FNDNWD  ( AXIS, START, B, E )
 
      IF ( B .GT. 0 ) THEN
         START = E + 1
         CALL FNDNWD ( AXIS, START, B, E )
 
         ZZONEWRD = B .EQ. 0
 
      ELSE
         ZZONEWRD = .FALSE.
      END IF
 
      RETURN
 
 
      END
