C$Procedure      CLFURN ( command line furnish )
 
      SUBROUTINE CLFURN ( CMLINE )
 
C$ Abstract
C
C     Look for the substring '-furnish <filename> on the command line
C     and do it.  Removing the furnish instruction from the string.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     UTILITY
C
C$ Declarations
 
      IMPLICIT NONE
      CHARACTER*(*)         CMLINE
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     CMLINE    I/O  String to examine for the template -furnish file
C
C$ Detailed_Input
C
C     CMLINE    On input, is a string (usually obtained from GETCML,
C               that may or may not have the command -furnish file.
C
C               Note that the case of -furnish is not significant
C
C$ Detailed_Output
C
C     CMLINE    Input string with the substring -furnish file removed.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     None.
C
C$ Particulars
C
C     This is utility that makes it easier to get kernel data into
C     your program using a standard interface.
C
C$ Examples
C
C     CALL GETCML ( LINE )
C     CALL CLFURN ( LINE )
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     W.L. Taber      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 16-MAR-2000 (WLT)
C
C
C-&
 
C$ Index_Entries
C
C     Furnish kernels from the command line.
C
C-&
C
C     SPICELIB Functions
C
      LOGICAL               EQSTR
      LOGICAL               RETURN
 
 
C
C     Local Variables
C
      INTEGER               START
      INTEGER               B
      INTEGER               E
      INTEGER               FB
      INTEGER               FE
C
C     Standard SPICE error handling.
C
      IF ( RETURN() ) THEN
         RETURN
      END IF
 
      CALL CHKIN ( 'CLFURN')
 
      START = 1
      B     = 1
      CALL FNDNWD ( CMLINE, START, B, E )
 
      DO WHILE ( B .NE. 0 )
 
         IF ( EQSTR( CMLINE(B:E), '-FURNISH' ) ) THEN
 
            START = E + 1
            CALL FNDNWD ( CMLINE, START, FB, FE )
 
            IF ( FB .NE. 0 ) THEN
               CALL FURNSH ( CMLINE(FB:FE) )
               CMLINE      ( B:FE ) = ' '
            END IF
            CALL CHKOUT ( 'CLFURN' )
            RETURN
 
         END IF
 
         START = E + 1
         CALL FNDNWD ( CMLINE, START, B, E )
      END DO
 
      CALL CHKOUT ( 'CLFURN' )
      RETURN
      END
